@@ -1,15 +1,17 @@
 context("ed_search")
 
-a <- ed_search(query = 'temperature')
-b <- ed_search(query = 'size')
+test_that("ed_search returns the correct", {
+  skip_on_cran()
 
-test_that("ed_search returns the correct class", {
+  a <- ed_search(query = 'temperature')
+  b <- ed_search(query = 'size')
+
+  # class
   expect_is(a, "ed_search")
   expect_is(a$info, "data.frame")
   expect_is(a$alldata, "list")
-})
 
-test_that("ed_search returns the correct dimensions", {
+  # dimensions
   expect_equal(length(a), 2)
   expect_equal(NCOL(a$info), 2)
   expect_equal(length(b), 2)
@@ -17,6 +19,8 @@ test_that("ed_search returns the correct dimensions", {
 })
 
 test_that("ed_search works with different ERDDAP servers", {
+  skip_on_cran()
+
   #' ## Marine Domain Awareness (MDA) (Italy)
   d <- ed_search("temperature", url = "https://bluehub.jrc.ec.europa.eu/erddap/")
   ## Marine Institute (Ireland)
@@ -32,6 +36,8 @@ test_that("ed_search works with different ERDDAP servers", {
 })
 
 test_that("ed_search fails well", {
+  skip_on_cran()
+
   expect_error(ed_search(), "\"query\" is missing, with no default")
   expect_error(ed_search("size", which = "stuff"), "should be one of")
 })
